@@ -249,7 +249,7 @@ class JsonObject:
     def to_dataframe(self):
         from pandas import DataFrame
         columns = self.get_columns()
-        return DataFrame(self.__dataframe_values__(), columns=columns)
+        return DataFrame([self.__dataframe_values__()], columns=columns)
 
 
 
@@ -521,7 +521,7 @@ class JsonList(list):
 
     def to_dataframe(self):
         from pandas import DataFrame
-        if issubclass(self.list_type(), JsonObject):
+        if issubclass(self.list_type, JsonObject):
             columns = self.list_type().get_columns()
             return DataFrame([i.__dataframe_values__() for i in self], columns=columns)
         else:
